@@ -9,19 +9,12 @@ get_df_names <- function(){
   if(class(df1_subs) == "call") df_name1 <- df_name1[2]
   if(class(df2_subs) == "call") df_name2 <- df_name2[2]
   # if either is a vector with pipe as first element then choose second
-  df_name1 <- ifelse(df_name1 %>% length > 1 & df_name1[1] == "%>%", 
-                     df_name1[2], df_name1[1])
-  df_name2 <- ifelse(df_name2 %>% length > 1 & df_name2[1] == "%>%", 
-                     df_name2[2], df_name2[1])
-  # if passed using a chain function, look for argument name
-  # only use if the first part of the chain isn't a fn
-  ee <- find_chain_parts()$lhs
-  if(!is.null(ee)){
-    if(!grepl("[(]", deparse(ee))){
-      df_name1 <- deparse(ee) 
-    }
-  }
-  # print(df_name1)
+  df_name1 <- ifelse(
+    df_name1 %>% length > 1 & df_name1[1] == "%>%", 
+    df_name1[2], df_name1[1])
+  df_name2 <- ifelse(
+    df_name2 %>% length > 1 & df_name2[1] == "%>%", 
+    df_name2[2], df_name2[1])
   # if the length is still greater than 1, then use default names
   if(df_name1 %>% length > 1) df_name1 <- "df1"
   if(df_name2 %>% length > 1) df_name2 <- "df2"
@@ -29,6 +22,9 @@ get_df_names <- function(){
   if(!is.null(df_name2) & !is.na(df_name2) & (df_name1 == df_name2)){
     df_name2 <- paste0(df_name2, "_2")
   }
+  # if passed using a chain function, look for argument name
+  # only use if the first part of the chain isn't a fn
+  if(df_name1 == '.') df_name1 <- 'Piped data'
   return(list(df1 = df_name1, df2 = df_name2))
 }
 
@@ -36,4 +32,3 @@ get_df_names <- function(){
 get_df_names_test <- function(df1, df2 = NULL){
   return(get_df_names())
 }
-
